@@ -5,10 +5,13 @@ use warnings FATAL => 'all';
 use File::Spec::Functions qw(catdir catfile catpath);
 use File::Path qw(make_path);
 use File::Copy qw(copy);
+use Cwd qw(abs_path);
 use parent 'Module::Build';
-use Exporter qw( import );    #export functionality to consumers
-our @EXPORT_OK =
-  (qw(create_build_script process_etc_files process_public_files process_templates_files));
+use Exporter qw( import );    #export functionality to Ado::BuildPlugin etc..
+our @EXPORT_OK = qw(
+  create_build_script process_etc_files
+  process_public_files process_templates_files
+  ACTION_perltidy ACTION_submit);
 
 
 #Shamelessly stollen from File::HomeDir::Windows
@@ -18,7 +21,7 @@ my $HOME =
   || (
     $ENV{HOMEDRIVE} && $ENV{HOMEPATH}
     ? catpath($ENV{HOMEDRIVE}, $ENV{HOMEPATH}, '')
-    : Cwd::abs_path('./')
+    : abs_path('./')
   );
 
 
@@ -127,6 +130,7 @@ sub ACTION_build {
 
 sub ACTION_dist {
     my $self = shift;
+    $self->depends_on("perltidy");
 
     #Make sure *log files are empty before including them into the distro
     _empty_log_files('blib/log');
@@ -141,14 +145,16 @@ sub ACTION_install {
 
     #Custom functionality before installation
     #here...
+    #TODO: Think about what to do with *.conf and *.sqlite files in case of upgrade!!!
+    #TODO: (upgrade)rotate logs - archive existing log files before emptying.
     $self->SUPER::ACTION_install;
 
     #Custom functionality after installation
+    #see below
     my $etc_dir = $self->install_path('etc');
     my $log_dir = $self->install_path('log');
 
     #make some files writable and/or readable only by the user that runs the application
-    #TODO: Think about what to do with *.conf and *.sqlite files in case of upgrade!!!
     for my $asset (qw(ado.conf plugins/routes.conf)) {
         chmod(0400, catfile($etc_dir, $asset))
           || Carp::carp("Problem with $etc_dir/$asset: $!");
@@ -166,6 +172,42 @@ sub ACTION_install {
     return;
 }
 
+sub ACTION_perltidy {
+    my $self = shift;
+    require File::Find;
+    eval { require Perl::Tidy } || do {
+        say "Perl::Tidy is not installed$/" . "Please install it and rerun ./Build perltidy";
+        return;
+    };
+    my @files;
+    File::Find::find(
+        {   no_chdir => 1,
+            wanted   => sub {
+                return if -d $File::Find::name;
+                my $file = $File::Find::name;
+                unlink $file and return if $file =~ /.bak/;
+                push @files, $file
+                  if $file =~ m/(\.conf|\.pm|.pl|Build\.PL|ado\|\.t)$/x;
+            },
+        },
+        map { abs_path($_) } (qw(bin lib etc t))
+    );
+
+    #We use ./.perltidyrc for all arguments
+    Perl::Tidy::perltidy(argv => [@files]);
+    foreach my $file (@files) {
+        unlink("$file.bak") if -f "$file.bak";
+    }
+    return;
+}
+
+sub ACTION_submit {
+    my $self = shift;
+    $self->depends_on("perltidy");
+    say "TODO: commit and push after tidying and testing and who knows what";
+    return;
+}
+
 #Sets Environmnent varable ADO_HOME in $HOME/.bashrc
 sub _set_env {
     my $self = shift;
@@ -226,7 +268,7 @@ sub do_create_readme {
         #HACK to create README from Ado::Manual.pod
         require Pod::Text;
         my $readme_from = catfile('lib', 'Ado', 'Manual.pod');
-        my $parser = Pod::Text->new(sentence => 0, indent => 2, width => 80);
+        my $parser = Pod::Text->new(sentence => 0, indent => 2, width => 76);
         $parser->parse_from_file($readme_from, 'README');
     }
     else {
@@ -256,6 +298,19 @@ Ado::Build - Custom routines for Ado installation
   use Ado::Build;
   my $builder = Ado::Build->new(..);
   $self->create_build_script();
+  
+  #on the command line
+  cd /path/to/cloned/Ado
+  perl Build.PL
+  ./Build
+  ./Build test
+  #change/add some code
+  ./Build test
+  ./Build perltidy
+  ./Build dist
+  ./Build submit
+  #.... and so on
+
 
 =head1 DESCRIPTION
 
@@ -264,7 +319,7 @@ custom functionality so we can install Ado in a location chosen by the user.
 
 
 This module and L<Ado::BuildPlugin> exist just because of the additional install paths
-that we use beside c<lib> and <bin>. These modules also can serve as examples 
+that we use beside C<lib> and C<bin>. These modules also can serve as examples 
 for your own builders if you have some custom things to do during 
 build, test, install and even if you need to add a new C<ACTION_*> to your setup.
 
@@ -277,12 +332,11 @@ the following ones.
 
 This method is called in C<Build.PL>.
 It checks if C<$ENV{ADO_HOME}> is set and if L<Ado> is installed there.
-If so suggests backup of the existing installation.
-in this method we also call c<add_build_element>
-for C<etc> C<public>  and C<log> folders. 
+If so suggests backup of the existing installation. In this method we also 
+call C<add_build_element> for C<etc> C<public>  and C<log> folders. 
 Also here is the functionality for prompting the user about the
 L<Module::Build/install_base> directory this will be C<$ENV{ADO_HOME}>.
-Finally we set all the c<install_path>s for the distro
+Finally we set all the C<install_path>s for the distro
 and we call C<$self-E<gt>SUPER::create_build_script>.
 
 =head2 process_etc_files
@@ -308,13 +362,13 @@ Returns void.
 
 =head2 ACTION_build
 
-We will put here custom functionality executed around the
-C<$self-E<gt>SUPER::ACTION_build>.
+We put here custom functionality executed around the
+C<$self-E<gt>SUPER::ACTION_build>. See the source for details.
 
 =head2 ACTION_dist
 
-We will put here custom functionality executed around the
-C<$self-E<gt>SUPER::ACTION_dist>.
+We put here custom functionality executed around the
+C<$self-E<gt>SUPER::ACTION_dist>. See the sources for details.
 
 =head2 ACTION_install
 
@@ -323,19 +377,35 @@ like C<etc/ado.sqlite> and to C<0400> of some files like C<etc/ado.conf>.
 Finally prompts the user to add C<$ENV{ADO_HOME}> to ~/.bashrc.
 This is currently not implemented for Windows. 
 The user will have to add C<$ENV{ADO_HOME}> as environment 
-variable him self.
+variable him self. You can put additional custom functionality here.
+
+=head2 ACTION_perltidy
+
+This is a custom action. Tidies all C<*.conf, *.pm, *.pl,*.t> 
+files found in directories C<./lib, ./t ./etc>
+in the distribution. uses the C<./pertidyrc> found in the root 
+directory of the distribution.
+This action is run first always when you run C<./Build dist>.
+
+  ./Build perltidy
+
+=head2 ACTION_submit
+
+TODO: commit and push after testing tidying and who knows what..
+
+  ./Build submit
+
 
-You can put additional custom functionality here.
 
 =head2 do_create_readme
 
-Creates the README file. It will be called during C<./Build dist> 
-if you set the property C<create_readme> in C<Build.PL>.
+Creates the README file from C<lib/Ado/Manual.pod>. 
 
 =head1 SEE ALSO
 
 L<Ado::BuildPlugin>,
 L<Module::Build::API>,
+L<Module::Build::Authoring>,
 L<Module::Build::Cookbook/ADVANCED_RECIPES>,
 Build.PL in Ado distribution directory.
 
