@@ -6,7 +6,10 @@ use File::Spec::Functions qw(catdir catfile catpath);
 use File::Path qw(make_path);
 use File::Copy qw(copy);
 use parent 'Module::Build';
-use Ado::Build qw(process_etc_files process_public_files process_templates_files);
+use Ado::Build qw(
+  process_etc_files process_public_files
+  process_templates_files
+  ACTION_perltidy ACTION_submit);
 
 sub create_build_script {
     my $self = shift;
@@ -55,12 +58,12 @@ Ado::BuildPlugin - Custom routines for Ado::Plugin::* installation
 
 This is a subclass of L<Module::Build>. 
 We use L<Module::Build::API> to add custom functionality 
-so we can install Ado  and it plugins in a location chosen by the user.
+so we can install Ado  and its plugins in a location chosen by the user.
 To use this module for installing your plugins
 $ENV{ADO_HOME} must be available and Ado installed there.
 
 This module and L<Ado::Build> exist because of the additional install paths
-that we use beside c<lib> and <bin>. These modules also can serve as examples 
+that we use beside C<lib> and C<bin>. These modules also can serve as examples 
 for your own builders if you have some custom things to do during 
 build, test, install and even if you need to add a new C<ACTION_*> to your setup.
 
@@ -75,7 +78,9 @@ C<process_templates_files> from L<Ado::Build>.
 =head2 create_build_script
 
 Creates a C<Build> script for instaling an L<Ado> plugin.
-
+This method will be called 
+during C<./Build dist> if you set the property C<create_readme> 
+in your C<Build.PL>.
 
 =head1 AUTHOR
 
